@@ -188,7 +188,10 @@ class Get_ASM_Consume:
 
                                 # 下方获取字段坑存在空值的情况，因前一日获取数据时无导致，可取0；
                                 # print(budget_order_id, int(budget_order_id), len(str(budget_order_id)))
-                                yes_spent_value = float(df[(df[0] == int(budget_order_id))].values[0][2])
+                                try:
+                                    yes_spent_value = float(df[(df[0] == int(budget_order_id))].values[0][2])
+                                except:
+                                    yes_spent_value = 0
                                 # 开始计算；
                                 if float(spent_value) != yes_spent_value:
                                     yes_run_num = round(spent_value - yes_spent_value, 2)  # 昨日消耗的；
